@@ -1,17 +1,19 @@
 use std::sync::mpsc;
 
-use windows::runtime::{implement, IUnknown, Interface, HRESULT};
+use windows::{
+    core::{IUnknown, Interface, HRESULT},
+    Win32::{
+        Foundation::{BOOL, PWSTR},
+        System::Com::IStream,
+    },
+};
+
+use windows_macros::implement;
 
 use crate::{
     pwstr::string_from_pwstr,
     Microsoft::{self, Web::WebView2::Win32::*},
-    Windows::{
-        self,
-        Win32::{
-            Foundation::{BOOL, PWSTR},
-            System::Com::IStream,
-        },
-    },
+    Windows,
 };
 
 pub trait ClosureArg {
@@ -27,13 +29,13 @@ pub trait InvokeArg<'a> {
 }
 
 impl ClosureArg for HRESULT {
-    type Output = windows::runtime::Result<()>;
+    type Output = windows::core::Result<()>;
 }
 
 impl<'a> InvokeArg<'a> for HRESULT {
     type Input = Self;
 
-    fn convert(input: HRESULT) -> windows::runtime::Result<()> {
+    fn convert(input: HRESULT) -> windows::core::Result<()> {
         input.ok()
     }
 }
@@ -79,7 +81,7 @@ pub type CompletedClosure<Arg1, Arg2> = Box<
     dyn FnOnce(
         <Arg1 as ClosureArg>::Output,
         <Arg2 as ClosureArg>::Output,
-    ) -> ::windows::runtime::Result<()>,
+    ) -> ::windows::core::Result<()>,
 >;
 
 /// Generic closure signature for [`event_callback`].
@@ -87,7 +89,7 @@ pub type EventClosure<Arg1, Arg2> = Box<
     dyn FnMut(
         <Arg1 as ClosureArg>::Output,
         <Arg2 as ClosureArg>::Output,
-    ) -> windows::runtime::Result<()>,
+    ) -> windows::core::Result<()>,
 >;
 
 #[completed_callback]
